==> whitehat-0.6.tar.gz: whitehat-0.6/README.md <==
[![PyPI - Downloads](https://img.shields.io/pypi/dm/whitehat?label=PyPI%20Downloads&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI](https://img.shields.io/pypi/v/whitehat?label=PyPI%20Version&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI - Status](https://img.shields.io/pypi/status/whitehat?label=Packages%20Status&logo=python&logoColor=lightblue)](https://pypi.org/project/whitehat#data)
[![GitHub repo size](https://img.shields.io/github/repo-size/EterNomm/Whitehat?label=Repo%20Size&logo=Github)](https://github.com/EterNomm/Whitehat)
[![GitHub stars](https://img.shields.io/github/stars/EterNomm/Whitehat?label=Stars)](https://github.com/EterNomm/Whitehat/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/EterNomm/Whitehat?label=Forks)](https://github.com/EterNomm/Whitehat/network)
[![Discord](https://img.shields.io/discord/887650006977347594?color=blue&label=EterNomm&logo=discord&logoColor=lightblue)](https://discord.com/invite/qpT2AeYZRN)
[![Discord](https://img.shields.io/discord/835863428450877441?color=blue&label=NekoIceTeam&logo=discord&logoColor=lightblue)](https://discord.com/invite/hNtA2uEb7J)

# Whitehat

⚠️ **WARNING THIS PYTHON LIBRARY FOR EDUCATIONAL PURPOSES ONLY** ⚠️

## Features
- DDoS (Can up to 1500+ Requests per seconds)
- Get Phonenumber Info
- Get IP Address Information
- Keylogger
- Port Scanner (In Development)
- More features soon!

## Install
- ### PIP
`pip install whitehat`

- ### Development Version
```
$ git clone https://github.com/EterNomm/Whitehat`
$ cd whitehat
$ pip install .
```
or
```
$ pip install git+https://github.com/EterNomm/Whitehat
```

## Example
[Click here](https://github.com/EterNomm/Whitehat/tree/main/examples)


## Other
- Want to be a contributor? [Pull Request](https://github.com/EterNomm/Whitehat/pulls) are welcome :3

- **Note from Developers :**
```
Sorry if we often update Whitehat (in one day can be 5+ updates).
because this version is still in BETA and we want version 1.0.0 (ALPHA version) to be released before 2022,
so we are pressed for time to quickly release the ALPHA version (stable version)

- Whitehat Developers
```

==> whitehat-0.6.1.tar.gz: whitehat-0.6.1/README.md <==
[![PyPI - Downloads](https://img.shields.io/pypi/dm/whitehat?label=PyPI%20Downloads&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI](https://img.shields.io/pypi/v/whitehat?label=PyPI%20Version&logo=pypi&logoColor=yellow)](https://pypi.org/project/whitehat)
[![PyPI - Status](https://img.shields.io/pypi/status/whitehat?label=Packages%20Status&logo=python&logoColor=lightblue)](https://pypi.org/project/whitehat#data)
[![GitHub repo size](https://img.shields.io/github/repo-size/EterNomm/Whitehat?label=Repo%20Size&logo=Github)](https://github.com/EterNomm/Whitehat)
[![GitHub stars](https://img.shields.io/github/stars/EterNomm/Whitehat?label=Stars)](https://github.com/EterNomm/Whitehat/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/EterNomm/Whitehat?label=Forks)](https://github.com/EterNomm/Whitehat/network)
[![Discord](https://img.shields.io/discord/887650006977347594?color=blue&label=EterNomm&logo=discord&logoColor=lightblue)](https://discord.com/invite/qpT2AeYZRN)
[![Discord](https://img.shields.io/discord/835863428450877441?color=blue&label=NekoIceTeam&logo=discord&logoColor=lightblue)](https://discord.com/invite/hNtA2uEb7J)

# Whitehat

⚠️ **WARNING THIS PYTHON PACKAGES FOR EDUCATIONAL PURPOSES ONLY** ⚠️

## Features
- DDoS (Can up to 1500+ Requests per seconds)
- Get Phonenumber Info
- Get IP Address Information
- Keylogger
- Port Scanner (In Development)
- More features soon!

## Install
- ### PIP
`pip install whitehat`

- ### Development Version
```
$ git clone https://github.com/EterNomm/Whitehat`
$ cd whitehat
$ pip install .
```
or
```
$ pip install git+https://github.com/EterNomm/Whitehat
```

## Example
[Click here](https://github.com/EterNomm/Whitehat/tree/main/examples)


## Other
- Want to be a contributor? [Pull Request](https://github.com/EterNomm/Whitehat/pulls) are welcome :3

- **Note from Developers :**
```
Sorry if we often update Whitehat (in one day can be 5+ updates).
because this version is still in BETA and we want version 1.0.0 (ALPHA version) to be released before 2022,
so we are pressed for time to quickly release the ALPHA version (stable version)

- Whitehat Developers
```
